Welcome to Heritage.py's documentation!
=======================================

.. image:: https://img.shields.io/pypi/v/heritage
        :target: https://pypi.python.org/pypi/heritage

.. image:: https://readthedocs.org/projects/heritage-py/badge/?version=latest
        :target: https://heritage-py.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status

.. image:: https://img.shields.io/pypi/pyversions/heritage
        :target: https://pypi.python.org/pypi/heritage
        :alt: Python Version Support

.. image:: https://img.shields.io/github/issues/hrishikeshrt/heritage
        :target: https://github.com/hrishikeshrt/heritage/issues
        :alt: GitHub Issues

.. image:: https://img.shields.io/github/followers/hrishikeshrt?style=social
        :target: https://github.com/hrishikeshrt
        :alt: GitHub Followers

.. image:: https://img.shields.io/twitter/follow/hrishikeshrt?style=social
        :target: https://twitter.com/hrishikeshrt
        :alt: Twitter Followers


Heritage.py is a python interface to `The Sanskrit Heritage Site`_.

.. _`The Sanskrit Heritage Site`: https://sanskrit.inria.fr/index.en.html

* Free software: GNU General Public License v3
* Documentation: https://heritage-py.readthedocs.io.


Features
--------

* Morphological Analysis
* Sandhi Formation
* Declensions
* Conjugations


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   installation
   usage
   modules
   contributing
   authors
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
